@@ -92,8 +92,7 @@ impl PackageGraph {
         let package_count = self.data.packages.len();
         if node_count != package_count {
             return Err(Error::PackageGraphInternalError(format!(
-                "number of nodes = {} different from packages = {}",
-                node_count, package_count,
+                "number of nodes = {node_count} different from packages = {package_count}",
             )));
         }
 
@@ -114,8 +113,7 @@ impl PackageGraph {
                     let metadata2_id = metadata2.map(|metadata| metadata.id());
                     if !matches!(metadata2_id, Ok(id) if id == package_id) {
                         return Err(Error::PackageGraphInternalError(format!(
-                            "package {} has workspace path {:?} but query by path returned {:?}",
-                            package_id, workspace_path, metadata2_id,
+                            "package {package_id} has workspace path {workspace_path:?} but query by path returned {metadata2_id:?}",
                         )));
                     }
 
@@ -134,8 +132,7 @@ impl PackageGraph {
                     // This package is not in the workspace.
                     if workspace_ids.contains(package_id) {
                         return Err(Error::PackageGraphInternalError(format!(
-                            "package {} has no workspace path but is in workspace",
-                            package_id,
+                            "package {package_id} has no workspace path but is in workspace",
                         )));
                     }
                 }
@@ -205,8 +202,7 @@ impl PackageGraph {
                 // See https://github.com/steveklabnik/semver/issues/98.
                 if !cargo_version_matches(req, to_version) {
                     return Err(Error::PackageGraphInternalError(format!(
-                        "{} -> {}: version ({}) doesn't match requirement ({:?})",
-                        package_id, to_id, to_version, req,
+                        "{package_id} -> {to_id}: version ({to_version}) doesn't match requirement ({req:?})",
                     )));
                 }
 
@@ -216,8 +212,7 @@ impl PackageGraph {
 
                 if !is_any {
                     return Err(Error::PackageGraphInternalError(format!(
-                        "{} -> {}: no edge info found",
-                        package_id, to_id,
+                        "{package_id} -> {to_id}: no edge info found",
                     )));
                 }
             }
@@ -517,7 +512,7 @@ impl<'g> Workspace<'g> {
     }
 
     /// Returns an iterator over package metadatas, sorted by the path they're in.
-    pub fn iter(&self) -> impl ExactSizeIterator<Item = PackageMetadata<'g>> {
+    pub fn iter(&self) -> impl ExactSizeIterator<Item = PackageMetadata<'g>> + use<'g> {
         self.iter_by_path().map(|(_, package)| package)
     }
 
@@ -525,7 +520,7 @@ impl<'g> Workspace<'g> {
     /// they're in.
     pub fn iter_by_path(
         &self,
-    ) -> impl ExactSizeIterator<Item = (&'g Utf8Path, PackageMetadata<'g>)> {
+    ) -> impl ExactSizeIterator<Item = (&'g Utf8Path, PackageMetadata<'g>)> + use<'g> {
         let graph = self.graph;
         self.inner.members_by_path.iter().map(move |(path, id)| {
             (
@@ -536,7 +531,9 @@ impl<'g> Workspace<'g> {
     }
 
     /// Returns an iterator over workspace names and package metadatas, sorted by names.
-    pub fn iter_by_name(&self) -> impl ExactSizeIterator<Item = (&'g str, PackageMetadata<'g>)> {
+    pub fn iter_by_name(
+        &self,
+    ) -> impl ExactSizeIterator<Item = (&'g str, PackageMetadata<'g>)> + use<'g> {
         let graph = self.graph;
         self.inner
             .members_by_name
@@ -546,7 +543,7 @@ impl<'g> Workspace<'g> {
 
     /// Returns an iterator over package IDs for workspace members. The package IDs will be returned
     /// in the same order as `members`, sorted by the path they're in.
-    pub fn member_ids(&self) -> impl ExactSizeIterator<Item = &'g PackageId> {
+    pub fn member_ids(&self) -> impl ExactSizeIterator<Item = &'g PackageId> + use<'g> {
         self.inner.members_by_path.values()
     }
 
@@ -629,7 +626,7 @@ mod workspace_rayon {
         /// Returns a parallel iterator over package metadatas, sorted by workspace path.
         ///
         /// Requires the `rayon1` feature to be enabled.
-        pub fn par_iter(&self) -> impl ParallelIterator<Item = PackageMetadata<'g>> {
+        pub fn par_iter(&self) -> impl ParallelIterator<Item = PackageMetadata<'g>> + use<'g> {
             self.par_iter_by_path().map(|(_, package)| package)
         }
 
@@ -639,7 +636,7 @@ mod workspace_rayon {
         /// Requires the `rayon1` feature to be enabled.
         pub fn par_iter_by_path(
             &self,
-        ) -> impl ParallelIterator<Item = (&'g Utf8Path, PackageMetadata<'g>)> {
+        ) -> impl ParallelIterator<Item = (&'g Utf8Path, PackageMetadata<'g>)> + use<'g> {
             let graph = self.graph;
             self.inner
                 .members_by_path
@@ -658,7 +655,7 @@ mod workspace_rayon {
         /// Requires the `rayon1` feature to be enabled.
         pub fn par_iter_by_name(
             &self,
-        ) -> impl ParallelIterator<Item = (&'g str, PackageMetadata<'g>)> {
+        ) -> impl ParallelIterator<Item = (&'g str, PackageMetadata<'g>)> + use<'g> {
             let graph = self.graph;
             self.inner
                 .members_by_name
@@ -749,18 +746,18 @@ impl<'g> PackageMetadata<'g> {
     pub fn direct_links_directed(
         &self,
         direction: DependencyDirection,
-    ) -> impl Iterator<Item = PackageLink<'g>> + 'g {
+    ) -> impl Iterator<Item = PackageLink<'g>> + 'g + use<'g> {
         self.direct_links_impl(direction.into())
     }
 
     /// Returns `PackageLink` instances corresponding to the direct dependencies for this package.
-    pub fn direct_links(&self) -> impl Iterator<Item = PackageLink<'g>> + 'g {
+    pub fn direct_links(&self) -> impl Iterator<Item = PackageLink<'g>> + 'g + use<'g> {
         self.direct_links_impl(Outgoing)
     }
 
     /// Returns `PackageLink` instances corresponding to the packages that directly depend on this
     /// one.
-    pub fn reverse_direct_links(&self) -> impl Iterator<Item = PackageLink<'g>> + 'g {
+    pub fn reverse_direct_links(&self) -> impl Iterator<Item = PackageLink<'g>> + 'g + use<'g> {
         self.direct_links_impl(Incoming)
     }
 
@@ -982,7 +979,7 @@ impl<'g> PackageMetadata<'g> {
     /// For more, see [Cargo
     /// Targets](https://doc.rust-lang.org/nightly/cargo/reference/cargo-targets.html#cargo-targets)
     /// in the Cargo reference.
-    pub fn build_targets(&self) -> impl Iterator<Item = BuildTarget<'g>> {
+    pub fn build_targets(&self) -> impl Iterator<Item = BuildTarget<'g>> + use<'g> {
         self.inner.build_targets.iter().map(BuildTarget::new)
     }
 
@@ -1039,7 +1036,7 @@ impl<'g> PackageMetadata<'g> {
     ///
     /// A named feature is listed in the `[features]` section of `Cargo.toml`. For more, see
     /// [the reference](https://doc.rust-lang.org/cargo/reference/manifest.html#the-features-section).
-    pub fn named_features(&self) -> impl Iterator<Item = &'g str> + 'g {
+    pub fn named_features(&self) -> impl Iterator<Item = &'g str> + 'g + use<'g> {
         self.named_features_full()
             .map(|(_, named_feature, _)| named_feature)
     }
@@ -1065,7 +1062,10 @@ impl<'g> PackageMetadata<'g> {
         }
     }
 
-    fn direct_links_impl(&self, dir: Direction) -> impl Iterator<Item = PackageLink<'g>> + 'g {
+    fn direct_links_impl(
+        &self,
+        dir: Direction,
+    ) -> impl Iterator<Item = PackageLink<'g>> + 'g + use<'g> {
         self.graph.dep_links_ixs_directed(self.package_ix(), dir)
     }
 
@@ -1107,7 +1107,7 @@ impl<'g> PackageMetadata<'g> {
     }
 
     #[allow(dead_code)]
-    pub(super) fn all_feature_nodes(&self) -> impl Iterator<Item = FeatureNode> + 'g {
+    pub(super) fn all_feature_nodes(&self) -> impl Iterator<Item = FeatureNode> + 'g + use<'g> {
         let package_ix = self.package_ix();
         iter::once(FeatureNode::new(
             self.package_ix(),
@@ -1125,7 +1125,8 @@ impl<'g> PackageMetadata<'g> {
 
     pub(super) fn named_features_full(
         &self,
-    ) -> impl Iterator<Item = (FeatureIndexInPackage, &'g str, &'g [NamedFeatureDep])> + 'g {
+    ) -> impl Iterator<Item = (FeatureIndexInPackage, &'g str, &'g [NamedFeatureDep])> + 'g + use<'g>
+    {
         self.inner
             .named_features
             .iter()
@@ -1143,7 +1144,7 @@ impl<'g> PackageMetadata<'g> {
 
     pub(super) fn optional_deps_full(
         &self,
-    ) -> impl Iterator<Item = (FeatureIndexInPackage, &'g str)> + 'g {
+    ) -> impl Iterator<Item = (FeatureIndexInPackage, &'g str)> + 'g + use<'g> {
         self.inner
             .optional_deps
             .iter()
@@ -1328,9 +1329,9 @@ impl<'g> PackageSource<'g> {
 impl fmt::Display for PackageSource<'_> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
-            PackageSource::Workspace(path) => write!(f, "{}", path),
-            PackageSource::Path(path) => write!(f, "{}", path),
-            PackageSource::External(source) => write!(f, "{}", source),
+            PackageSource::Workspace(path) => write!(f, "{path}"),
+            PackageSource::Path(path) => write!(f, "{path}"),
+            PackageSource::External(source) => write!(f, "{source}"),
         }
     }
 }
@@ -1596,7 +1597,7 @@ impl fmt::Display for ExternalSource<'_> {
                     GitReq::Rev(rev) => write!(f, "{}{}", Self::REV_EQ, rev)?,
                     GitReq::Default => {}
                 };
-                write!(f, "#{}", resolved)
+                write!(f, "#{resolved}")
             }
         }
     }
@@ -1979,7 +1980,7 @@ impl<'g> DependencyReq<'g> {
     /// Returns a list of all features possibly enabled by this dependency. This includes features
     /// that are only turned on if the dependency is optional, or features enabled by inactive
     /// platforms.
-    pub fn features(&self) -> impl Iterator<Item = &'g str> {
+    pub fn features(&self) -> impl Iterator<Item = &'g str> + use<'g> {
         self.inner.all_features()
     }
 
@@ -2127,8 +2128,8 @@ impl NamedFeatureDep {
 impl fmt::Display for NamedFeatureDep {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
-            Self::NamedFeature(feature) => write!(f, "{}", feature),
-            Self::OptionalDependency(dep_name) => write!(f, "dep:{}", dep_name),
+            Self::NamedFeature(feature) => write!(f, "{feature}"),
+            Self::OptionalDependency(dep_name) => write!(f, "dep:{dep_name}"),
             Self::DependencyNamedFeature {
                 dep_name,
                 feature,
