@@ -68,6 +68,39 @@ fn debug_impls() {
     );
 }
 
+// Ensure that Debug impls work for borrowed items, including diff
+// implementations.
+#[test]
+fn debug_impls_borrowed() {
+    let before = id_ord_map! {
+        BorrowedItem { key1: "a", key2: b"b0", key3: Path::new("path0") },
+        BorrowedItem { key1: "b", key2: b"b1", key3: Path::new("path1") },
+        BorrowedItem { key1: "c", key2: b"b2", key3: Path::new("path2") },
+    };
+
+    assert_eq!(
+        format!("{before:?}"),
+        r#"{"a": BorrowedItem { key1: "a", key2: [98, 48], key3: "path0" }, "b": BorrowedItem { key1: "b", key2: [98, 49], key3: "path1" }, "c": BorrowedItem { key1: "c", key2: [98, 50], key3: "path2" }}"#
+    );
+
+    #[cfg(feature = "daft")]
+    {
+        use daft::Diffable;
+
+        let after = id_ord_map! {
+            BorrowedItem { key1: "a", key2: b"b0", key3: Path::new("path0") },
+            BorrowedItem { key1: "c", key2: b"b3", key3: Path::new("path3") },
+            BorrowedItem { key1: "d", key2: b"b4", key3: Path::new("path4") },
+        };
+
+        let diff = before.diff(&after);
+        assert_eq!(
+            format!("{diff:?}"),
+            r#"Diff { common: {"a": IdLeaf { before: BorrowedItem { key1: "a", key2: [98, 48], key3: "path0" }, after: BorrowedItem { key1: "a", key2: [98, 48], key3: "path0" } }, "c": IdLeaf { before: BorrowedItem { key1: "c", key2: [98, 50], key3: "path2" }, after: BorrowedItem { key1: "c", key2: [98, 51], key3: "path3" } }}, added: {"d": BorrowedItem { key1: "d", key2: [98, 52], key3: "path4" }}, removed: {"b": BorrowedItem { key1: "b", key2: [98, 49], key3: "path1" }} }"#
+        );
+    }
+}
+
 #[test]
 fn test_compact_chaos() {
     let mut map = IdOrdMap::<TestItem>::make_new();
@@ -145,7 +178,7 @@ fn test_insert_unique() {
 
     // Test that the RefMut Debug impl looks good.
     assert!(
-        format!("{:?}", e1).starts_with(
+        format!("{e1:?}").starts_with(
             r#"TestItem { key1: 5, key2: 'a', key3: "y", value: "v""#,
         ),
         "RefMut Debug impl should forward to TestItem",
@@ -493,7 +526,7 @@ fn borrowed_item() {
     // (supporting this requires a little bit of unsafe code to get the
     // lifetimes to line up).
     fn fmt_debug(map: &IdOrdMap<BorrowedItem<'_>>) -> String {
-        format!("{:?}", map)
+        format!("{map:?}")
     }
 
     static DEBUG_OUTPUT: &str = "{\"bar\": BorrowedItem { \
@@ -501,7 +534,7 @@ fn borrowed_item() {
         \"foo\": BorrowedItem { \
         key1: \"foo\", key2: [102, 111, 111], key3: \"foo\" }}";
 
-    assert_eq!(format!("{:?}", map), DEBUG_OUTPUT);
+    assert_eq!(format!("{map:?}"), DEBUG_OUTPUT);
     assert_eq!(fmt_debug(&map), DEBUG_OUTPUT);
 
     // Try using the entry API against the borrowed item.
